@@ -5,6 +5,7 @@ from sys import stdout
 import shutil
 from platform import uname
 from tempfile import mkdtemp
+import parmed
 
 import mdtraj
 from simtk import openmm as mm
@@ -469,6 +470,15 @@ class MDSimulation():
         if self.progress_out=='stdout':
             self.progress_out = stdout
 
+        if isinstance(self.parmed_structure,dict):
+            pmd = parmed.structure.Structure()
+            pmd.__setstate__(self.parmed_structure)
+            #prune any extra exclusions
+            for i in pmd.atoms:
+                i._exclusion_partners = list(set(i._exclusion_partners))
+            self.parmed_structure = pmd
+
+
         if self.centering:
             self.center_coordinates()
 
@@ -608,6 +618,7 @@ class MDSimulation():
         del self.simulation
         del self.system
         del self.platform
+        self.parmed_structure = self.parmed_structure.__getstate__()
         try:
             del self.metaD
         except AttributeError:
@@ -697,7 +708,10 @@ class MDSimulation():
             else:
                 raise ValueError('state report interval must have units, got {}'.format(self.state_interval))
 
-            file_name = os.path.join(self.cwd, self.state_out)
+            if isinstance(self.state_out,str):
+                file_name = os.path.join(self.cwd, self.state_out)
+            else:
+                file_name = self.state_out
             state_report_steps = int(round(state_int))
 
             if state_report_steps == 0:
@@ -788,7 +802,7 @@ class MDSimulation():
 
         current_box = state.getPeriodicBoxVectors()
 
-        self.coordinates = np.array(self.positions.in_units_of(unit.angstrom) / unit.angstrom)
+        self.coordinates = np.array(self.positions.value_in_unit(unit.angstrom))
         self.parmed_structure.positions = self.positions
         self.parmed_structure.box_vectors = current_box
 
