@@ -113,7 +113,7 @@ class SegmentMappingSim(MetadynamicSimulation):
             distances = np.array(CVs)[:, 0]
         else:
             if scan_clock<self.max_scan_time:
-                print('ligand reached unbinding distance, proceeding with forced sampling')
+                print('ligand reached unbinding distance in {}, proceeding with forced sampling'.format(scan_clock))
             else:
                 print('failed to unbind in max_scan_time, proceeding anyway')
 
@@ -124,8 +124,6 @@ class SegmentMappingSim(MetadynamicSimulation):
         #find traj frames where the CV is evenly spaced along num_seg segments
         segment_targets = np.linspace(np.min(distances), self.unbound_distance, self.num_segs)
 
-        sorted_distances = distances.sort()
-
         segment_frames = []
         for target in segment_targets:
             idx = (np.abs(distances - target)).argmin()
