@@ -205,6 +205,15 @@ def find_radius_and_center(ligand_pos, radius_scale_factor):
     return rcyl,cog
 
 def find_flat_bottom_radius(ligand_pos, prot_pos, scale_factor=.8):
+    """
+    Find the point on the protein furthest from the ligand coordinates specified and return the distance between those
+    two points.
+
+    :param ligand_pos: np.array
+    :param prot_pos: np.array
+    :param scale_factor: float
+    :return: float
+    """
 
     cog = np.mean(ligand_pos, axis=0)
 
@@ -271,6 +280,7 @@ def get_angle_particle_coords(ligand_pos, prot_pos):
 def dist(a,b):
     """
     cartesian distance between two coordinates.
+
     :param a: numpy array
     :param b: numpy array
     :return: float
